@@ -1,11 +1,12 @@
 ## File Name: class.accuracy.rasch.R
-## File Version: 0.12
-############################################################
-# classification accuracy in the Rasch model
-class.accuracy.rasch <-
-function( cutscores, b, meantheta, sdtheta, theta.l, n.sims=0, seed=988){
+## File Version: 0.15
+
+
+#*** classification accuracy in the Rasch model
+class.accuracy.rasch <- function( cutscores, b, meantheta, sdtheta, theta.l,
+        n.sims=0)
+{
     dat0 <- matrix( 1, ncol=length(b), nrow=length(theta.l))
-    set.seed(seed)
     cat("Cut Scores \n")
     print( cutscores, digits=3 )
 
@@ -16,15 +17,13 @@ function( cutscores, b, meantheta, sdtheta, theta.l, n.sims=0, seed=988){
     semle <- rasch.info.mle(dat=dat0, theta=theta.l, b=b )
     wgttheta <- stats::dnorm( theta.l, mean=meantheta, sd=sdtheta )
     wgttheta <- wgttheta / sum( wgttheta )
-
     # distribution of estimated theta values
     m1 <- matrix( NA, nrow=L, ncol=L )
     for (tt in 1:L ){
-        # tt <- 1
         w.tt <- stats::dnorm( theta.l, mean=theta.l[tt], sd=semle[tt] )
         w.tt <- w.tt / sum( w.tt )
         m1[tt,] <- w.tt
-                    }
+    }
     # calculate probability classification
     m2 <- matrix( NA, CC, CC )
     classes <- paste("Class", 1:CC, sep="")
@@ -32,14 +31,12 @@ function( cutscores, b, meantheta, sdtheta, theta.l, n.sims=0, seed=988){
     colnames(m2) <- paste("Est", classes,sep="_")
     m0 <- matrix( wgttheta, L, L, byrow=FALSE  )
     for (cc in 1:CC){
-        # cc <- 1
         for (ee in 1:CC){
-            # ee <- 1
             ind.cc <- which( ( theta.l >=cutscores.long[cc] ) & ( theta.l < cutscores.long[cc+1] ) )
             ind.ee <- which( ( theta.l >=cutscores.long[ee] ) & ( theta.l < cutscores.long[ee+1] ) )
             m2[cc,ee] <- sum( m0[ind.cc, ind.ee ] * m1[ ind.cc, ind.ee ] )
-                    }
-            }
+        }
+    }
     stats <- data.frame( "agree0"=sum( diag(m2)) )
     stats$agree1 <- sum( m2 * ( abs( outer( 1:CC, 1:CC, "-" ) ) <=1 ) )
 
@@ -48,12 +45,12 @@ function( cutscores, b, meantheta, sdtheta, theta.l, n.sims=0, seed=988){
     for (cc in 1:CC){
         ind.cc <- which( ( theta.l >=cutscores.long[cc] ) & ( theta.l < cutscores.long[cc+1] ) )
         chance.prob[cc] <- sum( m0[ ind.cc, 1 ] )
-                }
+    }
     phi.c <- sum( chance.prob^2 )
     stats$kappa <- ( stats$agree0 - phi.c ) / ( 1 - phi.c )
     rownames(stats) <- "analytical"
-    #########################################
-    # accuracy by simulation
+
+    #*** accuracy by simulation
     if ( n.sims > 0 ){
         theta0 <- stats::rnorm(n.sims, mean=meantheta, sd=sdtheta )
         theta.sim <- data.frame( "theta.true"=theta0 )
@@ -81,11 +78,11 @@ function( cutscores, b, meantheta, sdtheta, theta.l, n.sims=0, seed=988){
         stats[2,"consistency"] <- mean( theta.sim$WLE2.class==theta.sim$WLE.class )
         cat("WLE consistency (correlation between two parallel forms)=" )
         cat( round( stats::cor( theta.sim$WLE, theta.sim$WLE2 ), 3 ), "\n")
-                    }
+    }
     cat("\nClassification accuracy and consistency\n")
     print( stats, digits=3 )
     cat("\nProbability classification table \n")
     print( round(m2,3), digits=3 )
     res <- list( "class.stats"=stats, "class.prob"=m2)
     invisible(res)
-        }
+}
