@@ -1,13 +1,13 @@
 ## File Name: create.ccov.R
-## File Version: 1.04
+## File Version: 1.07
 
 
-#*********************************************************
-# auxiliary function for creating a covariance matrix
-.create.ccov <- function( cc, data ){
+#**** auxiliary function for creating a covariance matrix
+create.ccov <- function( cc, data )
+{
     ccc <- cc$ccov.table
     I <- max( ccc$item1ID, ccc$item2ID )
-    ccov.matrix <- matrix( 0, I, I)
+    ccov.matrix <- matrix( 0, nrow=I, ncol=I)
     rownames(ccov.matrix) <- colnames(ccov.matrix) <- colnames(data)
     LL <- nrow(ccc)
     for (ll in 1:LL){
@@ -17,4 +17,6 @@
     }
     return( ccov.matrix)
 }
-#*********************************************************
+
+
+.create.ccov <- create.ccov
