@@ -1,49 +1,35 @@
 ## File Name: lsem_residualize.R
-## File Version: 0.34
+## File Version: 0.376
 
-##############################################
-# residualize data
+
+#**** residualize data
 lsem_residualize <- function( data, moderator, moderator.grid,
-        lavmodel, h=1.1, residualize=TRUE, eps=1E-8, verbose=TRUE )
+        lavmodel, h=1.1, residualize=TRUE, eps=1E-10, verbose=TRUE )
 {
     # lavaanify model
     lavaanstr <- lavaan::lavaanify( lavmodel  )
     vars <- unique( c( lavaanstr$rhs, lavaanstr$lhs ) )
     vars <- intersect( colnames(data), vars )
     data.mod <- data[, moderator ]
-    N <- length(data.mod)
-    # select nearest neighbor in moderator group for calculating residuals
-    G <- length(moderator.grid)
-    modgrid_index <- rep(1,N)
-    for (gg in 2:G){
-        modgrid_index <- ifelse( abs( data.mod - moderator.grid[ modgrid_index ] ) <
-                    abs( data.mod - moderator.grid[ gg ] ),
-                    modgrid_index, gg )
-    }
-    # compute weights for every grid point gg
-    weights <- matrix( NA, nrow=N, ncol=G )
-    sd.moderator <- stats::sd( data.mod, na.rm=TRUE)
-    bw <- h * sd.moderator * N^(-1/5)
-    moderator.density <- stats::density( data.mod, from=min(moderator.grid),
-                to=max(moderator.grid ), n=G )$y
-    moderator.density <- data.frame( "moderator"=moderator.grid,
-                "wgt"=moderator.density / sum(moderator.density) )
 
-    for (gg in 1:G){
-        # gg <- 1
-        xgg <- moderator.grid[gg]
-        wgt <- stats::dnorm( data.mod, mean=xgg, sd=bw ) /
-                    stats::dnorm( xgg, mean=xgg, sd=bw )
-        weights[,gg] <- ifelse( wgt < eps, eps, wgt )
-    }
+    # compute local weights
+    res <- lsem_local_weights(data.mod=data.mod, moderator.grid=moderator.grid, h=h)
+    weights <- res$weights
+    modgrid_index <- res$modgrid_index
+    N <- res$N
+    G <- res$G
+    sd.moderator <- res$sd.moderator
+    bw <- res$bw
+    moderator.density <- res$moderator.density
 
+    # residualize
     dat2 <- data
     V <- length(vars)
     residualized_interceps <- matrix( 0, nrow=G, ncol=V)
     colnames( residualized_interceps ) <- vars
     rownames( residualized_interceps ) <- round( moderator.grid, 3 )
 
-    if ( residualize){
+    if (residualize){
         if (verbose){
             cat("** Residualize Data\n")
             utils::flush.console()
@@ -75,6 +61,5 @@ lsem_residualize <- function( data, moderator, moderator.grid,
             residualized_interceps=residualized_interceps )
     return(res)
 }
-###############################################
 
 lsem.residualize <- lsem_residualize
