@@ -1,5 +1,5 @@
 ## File Name: lsem_weighted_cov.R
-## File Version: 0.09
+## File Version: 0.12
 
 lsem_weighted_cov <- function( x, weights )
 {
@@ -8,11 +8,11 @@ lsem_weighted_cov <- function( x, weights )
     eps <- 1E-100 * max(weights)
     weights_m <- sqrt( weights + eps ) * x_resp
     x[ is.na(x) ] <- 0
-    x_center <- lsem_weighted_mean( x=x, weights=weights )$mean
+    x_center <- lsem_weighted_mean( x=x, weights=weights_m )$mean
     XC <- matrix( x_center, nrow=nrow(x), ncol=ncol(x), byrow=TRUE )
     x <- x - XC
     weightsN <- crossprod(weights_m)
-    xw <- as.matrix( x * weights_m )
+    xw <- as.matrix( x * weights_m)
     covw <- crossprod(xw) / weightsN
     Nobs <- mean( weightsN[ ! upper.tri(weightsN) ] )
     res <- list( weightsN=weightsN, cov=covw, Nobs=Nobs )
